{
    "$graph": [
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#custom-bash.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#custom-bash.cwl/param"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "cat \"$0\" | grep \"$1\" | sed \"s/$1//g\"  > `basename $0`\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#custom-bash.cwl/script"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to run custom script set as `script` input with arguments from `param`.\nDefault script runs sed command over the input file and exports results to the file with the same name as input's basename\n",
            "id": "#custom-bash.cwl",
            "http://schema.org/name": "custom-bash",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/custom-bash.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Custom bash script runner",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#custom-bash.cwl/output_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/diffbind:v0.0.13"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#diffbind.cwl/analysis_method/method",
                            "symbols": [
                                "#diffbind.cwl/analysis_method/method/deseq2",
                                "#diffbind.cwl/analysis_method/method/edger",
                                "#diffbind.cwl/analysis_method/method/all"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-me"
                    },
                    "doc": "Method by which to analyze differential binding affinity. Default: all",
                    "id": "#diffbind.cwl/analysis_method"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-bl"
                    },
                    "doc": "Blocking attribute for multi-factor analysis. Minimum 2.\nEither names from --name1 or/and --name2 or array of strings that can be parsed by R to bool.\nIn the later case the order and size should correspond to [--read1]+[--read2].\nDefault: not applied\n",
                    "id": "#diffbind.cwl/blocked_attributes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-bf"
                    },
                    "doc": "Blocking attribute metadata file for multi-factor analysis. Headerless TSV/CSV file.\nFirst column - names from --name1 and --name2, second column - group name. --block is ignored\n",
                    "id": "#diffbind.cwl/blocked_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#diffbind.cwl/cutoff_param/cutoff",
                            "symbols": [
                                "#diffbind.cwl/cutoff_param/cutoff/pvalue",
                                "#diffbind.cwl/cutoff_param/cutoff/fdr"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-cp"
                    },
                    "doc": "Parameter to which cutoff should be applied (fdr or pvalue). Default: fdr",
                    "id": "#diffbind.cwl/cutoff_param"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "-cu"
                    },
                    "doc": "P-value or FDR cutoff for reported results. Default: 0.05",
                    "id": "#diffbind.cwl/cutoff_value"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-fs"
                    },
                    "doc": "Extend each read from its endpoint along the appropriate strand. Default: 125bp",
                    "id": "#diffbind.cwl/fragmentsize"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-mo"
                    },
                    "doc": "Min peakset overlap. Only include peaks in at least this many peaksets when generating consensus peakset. Default: 2",
                    "id": "#diffbind.cwl/min_overlap"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-mc"
                    },
                    "doc": "Min read counts. Exclude all merged intervals where the MAX raw read counts among all of the samples is smaller than the specified value. Default: 0",
                    "id": "#diffbind.cwl/min_read_counts"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-c1"
                    },
                    "doc": "Condition 1 name, single word with letters and numbers only. Default: condition_1",
                    "id": "#diffbind.cwl/name_cond_1"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-c2"
                    },
                    "doc": "Condition 2 name, single word with letters and numbers only. Default: condition_2",
                    "id": "#diffbind.cwl/name_cond_2"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "doc": "Output prefix. Default: diffbind",
                    "id": "#diffbind.cwl/output_prefix"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": "-p1"
                    },
                    "doc": "Peak files for condition 1. Minimim 2 files in format set with -pf",
                    "id": "#diffbind.cwl/peak_files_cond_1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": "-p2"
                    },
                    "doc": "Peak files for condition 2. Minimim 2 files in format set with -pf",
                    "id": "#diffbind.cwl/peak_files_cond_2"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#diffbind.cwl/peakformat/peakformat",
                            "symbols": [
                                "#diffbind.cwl/peakformat/peakformat/raw",
                                "#diffbind.cwl/peakformat/peakformat/bed",
                                "#diffbind.cwl/peakformat/peakformat/narrow",
                                "#diffbind.cwl/peakformat/peakformat/macs",
                                "#diffbind.cwl/peakformat/peakformat/bayes",
                                "#diffbind.cwl/peakformat/peakformat/tpic",
                                "#diffbind.cwl/peakformat/peakformat/sicer",
                                "#diffbind.cwl/peakformat/peakformat/fp4",
                                "#diffbind.cwl/peakformat/peakformat/swembl",
                                "#diffbind.cwl/peakformat/peakformat/csv",
                                "#diffbind.cwl/peakformat/peakformat/report"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-pf"
                    },
                    "doc": "Peak files format. One of [raw, bed, narrow, macs, bayes, tpic, sicer, fp4, swembl, csv, report]. Default: macs",
                    "id": "#diffbind.cwl/peakformat"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": "-r1"
                    },
                    "doc": "Read files for condition 1. Minimim 2 files in BAM format",
                    "id": "#diffbind.cwl/read_files_cond_1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "prefix": "-r2"
                    },
                    "doc": "Read files for condition 2. Minimim 2 files in BAM format",
                    "id": "#diffbind.cwl/read_files_cond_2"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-rd"
                    },
                    "doc": "Remove reads that map to exactly the same genomic position. Default: false",
                    "id": "#diffbind.cwl/remove_duplicates"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-n1"
                    },
                    "doc": "Sample names for condition 1. Default: basenames of -r1 without extensions",
                    "id": "#diffbind.cwl/sample_names_cond_1"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-n2"
                    },
                    "doc": "Sample names for condition 2. Default: basenames of -r2 without extensions",
                    "id": "#diffbind.cwl/sample_names_cond_2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-th"
                    },
                    "doc": "Threads number. Default: 1",
                    "id": "#diffbind.cwl/threads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-uc"
                    },
                    "doc": "Derive consensus peaks only from the common peaks within each condition. Min peakset overlap is ignored. Default: false",
                    "id": "#diffbind.cwl/use_common"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_normalized_counts_correlation_heatmap_deseq.png"
                    },
                    "doc": "Not filtered normalized counts correlation heatmap, DESeq2",
                    "id": "#diffbind.cwl/all_norm_counts_corr_heatmap_deseq"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_normalized_counts_correlation_heatmap_deseq_block.png"
                    },
                    "doc": "Not filtered normalized counts correlation heatmap, DESeq2 Blocked",
                    "id": "#diffbind.cwl/all_norm_counts_corr_heatmap_deseq_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_normalized_counts_correlation_heatmap_deseq_block.pdf"
                    },
                    "doc": "Not filtered normalized counts correlation heatmap, DESeq2 Blocked",
                    "id": "#diffbind.cwl/all_norm_counts_corr_heatmap_deseq_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_normalized_counts_correlation_heatmap_deseq.pdf"
                    },
                    "doc": "Not filtered normalized counts correlation heatmap, DESeq2",
                    "id": "#diffbind.cwl/all_norm_counts_corr_heatmap_deseq_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_normalized_counts_correlation_heatmap_edger.png"
                    },
                    "doc": "Not filtered normalized counts correlation heatmap, EdgeR",
                    "id": "#diffbind.cwl/all_norm_counts_corr_heatmap_edger"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_normalized_counts_correlation_heatmap_edger_block.png"
                    },
                    "doc": "Not filtered normalized counts correlation heatmap, EdgeR Blocked",
                    "id": "#diffbind.cwl/all_norm_counts_corr_heatmap_edger_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_normalized_counts_correlation_heatmap_edger_block.pdf"
                    },
                    "doc": "Not filtered normalized counts correlation heatmap, EdgeR Blocked",
                    "id": "#diffbind.cwl/all_norm_counts_corr_heatmap_edger_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_normalized_counts_correlation_heatmap_edger.pdf"
                    },
                    "doc": "Not filtered normalized counts correlation heatmap, EdgeR",
                    "id": "#diffbind.cwl/all_norm_counts_corr_heatmap_edger_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_pca_plot_deseq.png"
                    },
                    "doc": "PCA plot for not filtered bound sites, DESeq2",
                    "id": "#diffbind.cwl/all_pca_plot_deseq"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_pca_plot_deseq_block.png"
                    },
                    "doc": "PCA plot for not filtered bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/all_pca_plot_deseq_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_pca_plot_deseq_block.pdf"
                    },
                    "doc": "PCA plot for not filtered bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/all_pca_plot_deseq_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_pca_plot_deseq.pdf"
                    },
                    "doc": "PCA plot for not filtered bound sites, DESeq2",
                    "id": "#diffbind.cwl/all_pca_plot_deseq_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_pca_plot_edger.png"
                    },
                    "doc": "PCA plot for not filtered bound sites, EdgeR",
                    "id": "#diffbind.cwl/all_pca_plot_edger"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_pca_plot_edger_block.png"
                    },
                    "doc": "PCA plot for not filtered bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/all_pca_plot_edger_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_pca_plot_edger_block.pdf"
                    },
                    "doc": "PCA plot for not filtered bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/all_pca_plot_edger_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_pca_plot_edger.pdf"
                    },
                    "doc": "PCA plot for not filtered bound sites, EdgeR",
                    "id": "#diffbind.cwl/all_pca_plot_edger_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_peak_overlap_rate.png"
                    },
                    "doc": "All peak overlap rate plot",
                    "id": "#diffbind.cwl/all_peak_overlap_rate_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_peak_overlap_rate.pdf"
                    },
                    "doc": "All peak overlap rate plot",
                    "id": "#diffbind.cwl/all_peak_overlap_rate_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_report_deseq.tsv"
                    },
                    "doc": "Not filtered differential binding analysis report exported as TSV, DESeq2",
                    "id": "#diffbind.cwl/all_report_deseq"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_report_deseq_block.tsv"
                    },
                    "doc": "Not filtered differential binding analysis report exported as TSV, DESeq2 Blocked",
                    "id": "#diffbind.cwl/all_report_deseq_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_report_edger.tsv"
                    },
                    "doc": "Not filtered differential binding analysis report exported as TSV, EdgeR",
                    "id": "#diffbind.cwl/all_report_edger"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_all_report_edger_block.tsv"
                    },
                    "doc": "Not filtered differential binding analysis report exported as TSV, EdgeR Blocked",
                    "id": "#diffbind.cwl/all_report_edger_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_binding_heatmap_deseq.png"
                    },
                    "doc": "Binding heatmap for significantly differentially bound sites, DESeq2",
                    "id": "#diffbind.cwl/binding_heatmap_deseq"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_binding_heatmap_deseq_block.png"
                    },
                    "doc": "Binding heatmap for significantly differentially bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/binding_heatmap_deseq_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_binding_heatmap_deseq_block.pdf"
                    },
                    "doc": "Binding heatmap for significantly differentially bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/binding_heatmap_deseq_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_binding_heatmap_deseq.pdf"
                    },
                    "doc": "Binding heatmap for significantly differentially bound sites, DESeq2",
                    "id": "#diffbind.cwl/binding_heatmap_deseq_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_binding_heatmap_edger.png"
                    },
                    "doc": "Binding heatmap for significantly differentially bound sites, EdgeR",
                    "id": "#diffbind.cwl/binding_heatmap_edger"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_binding_heatmap_edger_block.png"
                    },
                    "doc": "Binding heatmap for significantly differentially bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/binding_heatmap_edger_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_binding_heatmap_edger_block.pdf"
                    },
                    "doc": "Binding heatmap for significantly differentially bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/binding_heatmap_edger_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_binding_heatmap_edger.pdf"
                    },
                    "doc": "Binding heatmap for significantly differentially bound sites, EdgeR",
                    "id": "#diffbind.cwl/binding_heatmap_edger_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_box_plot_deseq.png"
                    },
                    "doc": "Box plots of read distributions for significantly differentially bound sites, DESeq2",
                    "id": "#diffbind.cwl/boxplot_deseq"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_box_plot_deseq_block.png"
                    },
                    "doc": "Box plots of read distributions for significantly differentially bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/boxplot_deseq_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_box_plot_deseq_block.pdf"
                    },
                    "doc": "Box plots of read distributions for significantly differentially bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/boxplot_deseq_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_box_plot_deseq.pdf"
                    },
                    "doc": "Box plots of read distributions for significantly differentially bound sites, DESeq2",
                    "id": "#diffbind.cwl/boxplot_deseq_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_box_plot_edger.png"
                    },
                    "doc": "Box plots of read distributions for significantly differentially bound sites, EdgeR",
                    "id": "#diffbind.cwl/boxplot_edger"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_box_plot_edger_block.png"
                    },
                    "doc": "Box plots of read distributions for significantly differentially bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/boxplot_edger_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_box_plot_edger_block.pdf"
                    },
                    "doc": "Box plots of read distributions for significantly differentially bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/boxplot_edger_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_box_plot_edger.pdf"
                    },
                    "doc": "Box plots of read distributions for significantly differentially bound sites, EdgeR",
                    "id": "#diffbind.cwl/boxplot_edger_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_consensus_peak_venn_diagram.png"
                    },
                    "doc": "Consensus peak Venn Diagram",
                    "id": "#diffbind.cwl/consensus_peak_venn_diagram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_consensus_peak_venn_diagram.pdf"
                    },
                    "doc": "Consensus peak Venn Diagram",
                    "id": "#diffbind.cwl/consensus_peak_venn_diagram_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_normalized_counts_correlation_heatmap_deseq.png"
                    },
                    "doc": "Normalized counts correlation heatmap for significantly differentially bound sites, DESeq2",
                    "id": "#diffbind.cwl/diff_filtered_norm_counts_corr_heatmap_deseq"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_normalized_counts_correlation_heatmap_deseq_block.png"
                    },
                    "doc": "Normalized counts correlation heatmap for significantly differentially bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/diff_filtered_norm_counts_corr_heatmap_deseq_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_normalized_counts_correlation_heatmap_deseq_block.pdf"
                    },
                    "doc": "Normalized counts correlation heatmap for significantly differentially bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/diff_filtered_norm_counts_corr_heatmap_deseq_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_normalized_counts_correlation_heatmap_deseq.pdf"
                    },
                    "doc": "Normalized counts correlation heatmap for significantly differentially bound sites, DESeq2",
                    "id": "#diffbind.cwl/diff_filtered_norm_counts_corr_heatmap_deseq_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_normalized_counts_correlation_heatmap_edger.png"
                    },
                    "doc": "Normalized counts correlation heatmap for significantly differentially bound sites, EdgeR",
                    "id": "#diffbind.cwl/diff_filtered_norm_counts_corr_heatmap_edger"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_normalized_counts_correlation_heatmap_edger_block.png"
                    },
                    "doc": "Normalized counts correlation heatmap for significantly differentially bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/diff_filtered_norm_counts_corr_heatmap_edger_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_normalized_counts_correlation_heatmap_edger_block.pdf"
                    },
                    "doc": "Normalized counts correlation heatmap for significantly differentially bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/diff_filtered_norm_counts_corr_heatmap_edger_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_normalized_counts_correlation_heatmap_edger.pdf"
                    },
                    "doc": "Normalized counts correlation heatmap for significantly differentially bound sites, EdgeR",
                    "id": "#diffbind.cwl/diff_filtered_norm_counts_corr_heatmap_edger_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_pca_plot_deseq.png"
                    },
                    "doc": "PCA plot for significantly differentially bound sites, DESeq2",
                    "id": "#diffbind.cwl/diff_filtered_pca_plot_deseq"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_pca_plot_deseq_block.png"
                    },
                    "doc": "PCA plot for significantly differentially bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/diff_filtered_pca_plot_deseq_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_pca_plot_deseq_block.pdf"
                    },
                    "doc": "PCA plot for significantly differentially bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/diff_filtered_pca_plot_deseq_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_pca_plot_deseq.pdf"
                    },
                    "doc": "PCA plot for significantly differentially bound sites, DESeq2",
                    "id": "#diffbind.cwl/diff_filtered_pca_plot_deseq_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_pca_plot_edger.png"
                    },
                    "doc": "PCA plot for significantly differentially bound sites, EdgeR",
                    "id": "#diffbind.cwl/diff_filtered_pca_plot_edger"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_pca_plot_edger_block.png"
                    },
                    "doc": "PCA plot for significantly differentially bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/diff_filtered_pca_plot_edger_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_pca_plot_edger_block.pdf"
                    },
                    "doc": "PCA plot for significantly differentially bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/diff_filtered_pca_plot_edger_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_pca_plot_edger.pdf"
                    },
                    "doc": "PCA plot for significantly differentially bound sites, EdgeR",
                    "id": "#diffbind.cwl/diff_filtered_pca_plot_edger_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_report_deseq.tsv"
                    },
                    "doc": "Differential binding analysis report for significantly differentially bound sites exported as TSV, DESeq2",
                    "id": "#diffbind.cwl/diff_filtered_report_deseq"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_report_deseq_block.tsv"
                    },
                    "doc": "Differential binding analysis report for significantly differentially bound sites exported as TSV, DESeq2 Blocked",
                    "id": "#diffbind.cwl/diff_filtered_report_deseq_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_report_edger.tsv"
                    },
                    "doc": "Differential binding analysis report for significantly differentially bound sites exported as TSV, EdgeR",
                    "id": "#diffbind.cwl/diff_filtered_report_edger"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_report_edger_block.tsv"
                    },
                    "doc": "Differential binding analysis report for significantly differentially bound sites exported as TSV, EdgeR Blocked",
                    "id": "#diffbind.cwl/diff_filtered_report_edger_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_ma_plot_deseq.png"
                    },
                    "doc": "MA plot for significantly differentially bound sites, DESeq2",
                    "id": "#diffbind.cwl/ma_plot_deseq"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_ma_plot_deseq_block.png"
                    },
                    "doc": "MA plot for significantly differentially bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/ma_plot_deseq_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_ma_plot_deseq_block.pdf"
                    },
                    "doc": "MA plot for significantly differentially bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/ma_plot_deseq_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_ma_plot_deseq.pdf"
                    },
                    "doc": "MA plot for significantly differentially bound sites, DESeq2",
                    "id": "#diffbind.cwl/ma_plot_deseq_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_ma_plot_edger.png"
                    },
                    "doc": "MA plot for significantly differentially bound sites, EdgeR",
                    "id": "#diffbind.cwl/ma_plot_edger"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_ma_plot_edger_block.png"
                    },
                    "doc": "MA plot for significantly differentially bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/ma_plot_edger_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_ma_plot_edger_block.pdf"
                    },
                    "doc": "MA plot for significantly differentially bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/ma_plot_edger_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_ma_plot_edger.pdf"
                    },
                    "doc": "MA plot for significantly differentially bound sites, EdgeR",
                    "id": "#diffbind.cwl/ma_plot_edger_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_peak_overlap_correlation_heatmap.png"
                    },
                    "doc": "Peak overlap correlation heatmap",
                    "id": "#diffbind.cwl/peak_overlap_corr_heatmap"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_peak_overlap_correlation_heatmap.pdf"
                    },
                    "doc": "Peak overlap correlation heatmap",
                    "id": "#diffbind.cwl/peak_overlap_corr_heatmap_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_condition_1_peak_overlap_rate.png"
                    },
                    "doc": "Peak overlap rate plot, condition 1",
                    "id": "#diffbind.cwl/peak_overlap_rate_plot_cond_1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_condition_1_peak_overlap_rate.pdf"
                    },
                    "doc": "Peak overlap rate plot, condition 1",
                    "id": "#diffbind.cwl/peak_overlap_rate_plot_cond_1_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_condition_2_peak_overlap_rate.png"
                    },
                    "doc": "Peak overlap rate plot, condition 2",
                    "id": "#diffbind.cwl/peak_overlap_rate_plot_cond_2"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_condition_2_peak_overlap_rate.pdf"
                    },
                    "doc": "Peak overlap rate plot, condition 2",
                    "id": "#diffbind.cwl/peak_overlap_rate_plot_cond_2_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_counts_correlation_heatmap.png"
                    },
                    "doc": "Raw counts correlation heatmap",
                    "id": "#diffbind.cwl/raw_counts_corr_heatmap"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_raw_counts_correlation_heatmap.pdf"
                    },
                    "doc": "Raw counts correlation heatmap",
                    "id": "#diffbind.cwl/raw_counts_corr_heatmap_pdf"
                },
                {
                    "type": "File",
                    "id": "#diffbind.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "diffbind_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#diffbind.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "diffbind_stdout.log"
                    }
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_volcano_plot_deseq.png"
                    },
                    "doc": "Volcano plot for significantly differentially bound sites, DESeq2",
                    "id": "#diffbind.cwl/volcano_plot_deseq"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_volcano_plot_deseq_block.png"
                    },
                    "doc": "Volcano plot for for significantly differentially bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/volcano_plot_deseq_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_volcano_plot_deseq_block.pdf"
                    },
                    "doc": "Volcano plot for for significantly differentially bound sites, DESeq2 Blocked",
                    "id": "#diffbind.cwl/volcano_plot_deseq_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_volcano_plot_deseq.pdf"
                    },
                    "doc": "Volcano plot for significantly differentially bound sites, DESeq2",
                    "id": "#diffbind.cwl/volcano_plot_deseq_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_volcano_plot_edger.png"
                    },
                    "doc": "Volcano plot for for significantly differentially bound sites, EdgeR",
                    "id": "#diffbind.cwl/volcano_plot_edger"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_volcano_plot_edger_block.png"
                    },
                    "doc": "Volcano plot for for significantly differentially bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/volcano_plot_edger_blocked"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_volcano_plot_edger_block.pdf"
                    },
                    "doc": "Volcano plot for for significantly differentially bound sites, EdgeR Blocked",
                    "id": "#diffbind.cwl/volcano_plot_edger_blocked_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*_filtered_volcano_plot_edger.pdf"
                    },
                    "doc": "Volcano plot for for significantly differentially bound sites, EdgeR",
                    "id": "#diffbind.cwl/volcano_plot_edger_pdf"
                }
            ],
            "baseCommand": [
                "run_diffbind.R"
            ],
            "stdout": "diffbind_stdout.log",
            "stderr": "diffbind_stderr.log",
            "label": "DiffBind - Differential Binding Analysis of ChIP-Seq Peak Data",
            "doc": "Runs R script to compute differentially bound sites from multiple ChIP-seq experiments using affinity (quantitative) and occupancy data.\n",
            "id": "#diffbind.cwl",
            "http://schema.org/name": "DiffBind - Differential Binding Analysis of ChIP-Seq Peak Data",
            "http://schema.org/alternateName": "Compute differentially bound sites from multiple ChIP-seq experiments using affinity (quantitative) data.",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/diffbind.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage: /Users/kot4or/workspaces/cwl_ws/workflows/tools/dockerfiles/scripts/run_diffbind.R\n      [-h] -r1 READ1 [READ1 ...] -r2 READ2 [READ2 ...] -p1 PEAK1 [PEAK1 ...]\n      -p2 PEAK2 [PEAK2 ...] [-n1 [NAME1 [NAME1 ...]]]\n      [-n2 [NAME2 [NAME2 ...]]] [-bl [BLOCK [BLOCK ...]]]\n      [-pf {raw,bed,narrow,macs,bayes,tpic,sicer,fp4,swembl,csv,report}]\n      [-c1 CONDITION1] [-c2 CONDITION2] [-fs FRAGMENTSIZE] [-rd]\n      [-me {edger,deseq2,all}] [-mo MINOVERLAP] [-uc] [-mc MINCOUNTS]\n      [-cu CUTOFF] [-cp {pvalue,fdr}] [-th THREADS] [-pa PADDING] [-o OUTPUT]\n\nDifferential binding analysis of ChIP-Seq experiments using affinity (read\ncount) data\n\noptional arguments:\n  -h, --help            show this help message and exit\n  -r1 READ1 [READ1 ...], --read1 READ1 [READ1 ...]\n                        Read files for condition 1. Minimim 2 files in BAM\n                        format\n  -r2 READ2 [READ2 ...], --read2 READ2 [READ2 ...]\n                        Read files for condition 2. Minimim 2 files in BAM\n                        format\n  -p1 PEAK1 [PEAK1 ...], --peak1 PEAK1 [PEAK1 ...]\n                        Peak files for condition 1. Minimim 2 files in format\n                        set with -pf\n  -p2 PEAK2 [PEAK2 ...], --peak2 PEAK2 [PEAK2 ...]\n                        Peak files for condition 2. Minimim 2 files in format\n                        set with -pf\n  -n1 [NAME1 [NAME1 ...]], --name1 [NAME1 [NAME1 ...]]\n                        Sample names for condition 1. Default: basenames of\n                        -r1 without extensions\n  -n2 [NAME2 [NAME2 ...]], --name2 [NAME2 [NAME2 ...]]\n                        Sample names for condition 2. Default: basenames of\n                        -r2 without extensions\n  -bl [BLOCK [BLOCK ...]], --block [BLOCK [BLOCK ...]]\n                        Blocking attribute for multi-factor analysis. Minimum\n                        2. Either names from --name1 or/and --name2 or array\n                        of bool based on [read1]+[read2]. Default: not applied\n  -pf {raw,bed,narrow,macs,bayes,tpic,sicer,fp4,swembl,csv,report}, --peakformat {raw,bed,narrow,macs,bayes,tpic,sicer,fp4,swembl,csv,report}\n                        Peak files format. One of [raw, bed, narrow, macs,\n                        bayes, tpic, sicer, fp4, swembl, csv, report].\n                        Default: macs\n  -c1 CONDITION1, --condition1 CONDITION1\n                        Condition 1 name, single word with letters and numbers\n                        only. Default: condition_1\n  -c2 CONDITION2, --condition2 CONDITION2\n                        Condition 2 name, single word with letters and numbers\n                        only. Default: condition_2\n  -fs FRAGMENTSIZE, --fragmentsize FRAGMENTSIZE\n                        Extend each read from its endpoint along the\n                        appropriate strand. Default: 125bp\n  -rd, --removedup      Remove reads that map to exactly the same genomic\n                        position. Default: false\n  -me {edger,deseq2,all}, --method {edger,deseq2,all}\n                        Method by which to analyze differential binding\n                        affinity. Default: all\n  -mo MINOVERLAP, --minoverlap MINOVERLAP\n                        Min peakset overlap. Only include peaks in at least\n                        this many peaksets when generating consensus peakset.\n                        Default: 2\n  -uc, --usecommon      Derive consensus peaks only from the common peaks\n                        within each condition. Min peakset overlap and min\n                        read counts are ignored. Default: false\n  -mc MINCOUNTS, --mincounts MINCOUNTS\n                        Min read counts. Exclude all merged intervals where\n                        the MAX raw read counts among all of the samples is\n                        smaller than the specified value. Default: 0\n  -cu CUTOFF, --cutoff CUTOFF\n                        Cutoff for reported results. Applied to the parameter\n                        set with -cp. Default: 0.05\n  -cp {pvalue,fdr}, --cparam {pvalue,fdr}\n                        Parameter to which cutoff should be applied (fdr or\n                        pvalue). Default: fdr\n  -th THREADS, --threads THREADS\n                        Threads to use\n  -pa PADDING, --padding PADDING\n                        Padding for generated heatmaps. Default: 20\n  -o OUTPUT, --output OUTPUT\n                        Output prefix. Default: diffbind"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function(ext) { var root = inputs.input_filename.basename.split('.').slice(0,-1).join('.'); return (root == \"\")?inputs.input_filename.basename+ext:root+ext; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/iaintersect:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--a=",
                        "separate": false
                    },
                    "doc": "Annotation file, tsv",
                    "id": "#iaintersect.cwl/annotation_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "--sam_ignorechr=",
                        "separate": false
                    },
                    "doc": "The chromosome to be ignored, string\n",
                    "id": "#iaintersect.cwl/ignore_chr"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--in=",
                        "separate": false
                    },
                    "doc": "Input filename with MACS2 peak calling results, tsv",
                    "id": "#iaintersect.cwl/input_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "--log=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename('_iaintersect.log');\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Log filename\n",
                    "id": "#iaintersect.cwl/log_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 3,
                        "prefix": "--out=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename('_iaintersect.tsv');\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Base output file name, tsv\n",
                    "id": "#iaintersect.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "--promoter=",
                        "separate": false
                    },
                    "doc": "Promoter region around TSS, base pairs\n",
                    "id": "#iaintersect.cwl/promoter_bp"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "--upstream=",
                        "separate": false
                    },
                    "doc": "Upstream region before promoter, base pairs\n",
                    "id": "#iaintersect.cwl/upstream_bp"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.log_filename == \"\"){\n    return default_output_filename('_iaintersect.log');\n  } else {\n    return inputs.log_filename;\n  }\n}\n"
                    },
                    "id": "#iaintersect.cwl/log_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_filename == \"\"){\n    return default_output_filename('_iaintersect.tsv');\n  } else {\n    return inputs.output_filename;\n  }\n}\n"
                    },
                    "id": "#iaintersect.cwl/result_file"
                }
            ],
            "baseCommand": [
                "iaintersect"
            ],
            "doc": "Tool assigns each peak obtained from MACS2 to a gene and region (upstream, promoter, exon, intron, intergenic)\n\n`default_output_filename` function returns output filename with sufix set as `ext` argument. Function is called when\neither `output_filename` or `log_filename` inputs are not provided.\n",
            "id": "#iaintersect.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#iaintersect-metadata.yaml",
                "http://schema.org/name": "iaintersect",
                "http://schema.org/about": "Based on BioWardrobe iaintersect (https://github.com/cincinnati-childrens-hospital/biowardrobe/tree/master/src/iaintersect) The software assigns each peak obtained from MACS2 to a gene and region (upstream, promoter, exon, intron, intergenic).\n",
                "http://schema.org/url": "https://github.com/Barski-lab/iaintersect/blob/master/README.md",
                "http://schema.org/codeRepository": "https://github.com/Barski-lab/iaintersect",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/MIT"
                ],
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "0.0.1",
                    "http://schema.org/applicationCategory": "command line tool"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/discussionUrl": [
                    "https://github.com/Barski-lab/iaintersect/issues"
                ],
                "http://schema.org/creator": [
                    {
                        "class": "http://schema.org/Organization",
                        "http://schema.org/name": "Barski Research Lab",
                        "http://schema.org/member": [
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Andrey Kartashov",
                                "http://schema.org/description": "Main author"
                            },
                            {
                                "class": "http://schema.org/Person",
                                "http://schema.org/name": "Michael Kotliar",
                                "http://schema.org/description": "Update to work with files instead of DB"
                            }
                        ]
                    }
                ]
            },
            "http://schema.org/name": "iaintersect",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/iaintersect.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Usage:\n  iaintersect [options] --in=pathToFile --a=pathtoFile --out=pathToFile\n  --a                        \tTab-separated annotation file\n  --in                       \tInput filename with MACS2 peak calling results, xls\n  --log                      \tLog filename (default is ./logfile_def.log)\n  --out                      \tBase output file name\n  --promoter                 \tPromoter region around TSS in bp\n  --sam_ignorechr            \tThe chromosome to be ignored\n  --upstream                 \tUpstream region before promoter in bp\n"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var get_output_filename = function() { if (inputs.output_filename) { return inputs.output_filename; } return inputs.unsorted_file.location.split('/').slice(-1)[0]; };"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.2"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-k"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "-k, --key=POS1[,POS2]\nstart a key at POS1, end it at POS2 (origin 1)\n",
                    "id": "#linux-sort.cwl/key"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Name for generated output file\n",
                    "id": "#linux-sort.cwl/output_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#linux-sort.cwl/unsorted_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#linux-sort.cwl/sorted_file",
                    "outputBinding": {
                        "glob": "$(get_output_filename())"
                    }
                }
            ],
            "stdout": "$(get_output_filename())",
            "baseCommand": [
                "sort"
            ],
            "doc": "Tool sorts data from `unsorted_file` by key\n\n`default_output_filename` function returns file name identical to `unsorted_file`, if `output_filename` is not provided.\n",
            "id": "#linux-sort.cwl",
            "http://schema.org/name": "linux-sort",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/linux-sort.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Andrey Kartashov",
                                            "http://schema.org/email": "mailto:Andrey.Kartashov@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0001-9102-5681"
                                                }
                                            ]
                                        },
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var default_output_filename = function() { return inputs.input_bed.location.split('/').slice(-1)[0].split('.').slice(0,-1).join('.')+\".bb\"; };",
                        "var get_bed_type = function() { if (inputs.input_bed.location.split('.').slice(-1)[0].toLowerCase() == \"narrowpeak\"){ return \"bed6+4\"; } else if (inputs.input_bed.location.split('.').slice(-1)[0].toLowerCase() == \"broadpeak\"){ return \"bed6+3\"; } else { return null; } };",
                        "var get_bed_template = function() { if (inputs.input_bed.location.split('.').slice(-1)[0].toLowerCase() == \"narrowpeak\"){ return \"narrowpeak.as\"; } else if (inputs.input_bed.location.split('.').slice(-1)[0].toLowerCase() == \"broadpeak\"){ return \"broadpeak.as\"; } else { return null; } };"
                    ]
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "narrowpeak.as",
                            "entry": "table narrowPeak\n\"BED6+4 Peaks of signal enrichment based on pooled, normalized (interpreted) data.\"\n(\n  string  chrom;        \"Reference sequence chromosome or scaffold\"\n  uint    chromStart;   \"Start position in chromosome\"\n  uint    chromEnd;     \"End position in chromosome\"\n  string  name;\t        \"Name given to a region (preferably unique). Use . if no name is assigned\"\n  uint    score;        \"Indicates how dark the peak will be displayed in the browser (0-1000) \"\n  char[1] strand;       \"+ or - or . for unknown\"\n  float   signalValue;  \"Measurement of average enrichment for the region\"\n  float   pValue;       \"Statistical significance of signal value (-log10). Set to -1 if not used.\"\n  float   qValue;       \"Statistical significance with multiple-test correction applied (FDR -log10). Set to -1 if not used.\"\n  int     peak;         \"Point-source called for this peak; 0-based offset from chromStart. Set to -1 if no point-source called.\"\n)\n"
                        },
                        {
                            "entryname": "broadpeak.as",
                            "entry": "table broadPeak\n\"BED6+3 Peaks of signal enrichment based on pooled, normalized (interpreted) data.\"\n(\n  string  chrom;        \"Reference sequence chromosome or scaffold\"\n  uint    chromStart;   \"Start position in chromosome\"\n  uint    chromEnd;     \"End position in chromosome\"\n  string  name;\t        \"Name given to a region (preferably unique). Use . if no name is assigned.\"\n  uint    score;        \"Indicates how dark the peak will be displayed in the browser (0-1000)\"\n  char[1] strand;       \"+ or - or . for unknown\"\n  float   signalValue;  \"Measurement of average enrichment for the region\"\n  float   pValue;       \"Statistical significance of signal value (-log10). Set to -1 if not used.\"\n  float   qValue;       \"Statistical significance with multiple-test correction applied (FDR -log10). Set to -1 if not used.\"\n)\n"
                        }
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/ucscuserapps:v358"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 6,
                        "prefix": "-as=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return get_bed_template();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "For non-standard \"bedPlus\" fields put a definition of each field in a row in AutoSql format.\nBy default includes only three required BED fields: chrom, chromStart, chromEnd\n",
                    "id": "#ucsc-bedtobigbed.cwl/bed_template"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 5,
                        "prefix": "-type=",
                        "separate": false,
                        "valueFrom": "${\n    if (self == \"\"){\n      return get_bed_type();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Type of BED file in a form of bedN[+[P]]. By default bed3 to three required BED fields\n",
                    "id": "#ucsc-bedtobigbed.cwl/bed_type"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 7,
                        "prefix": "-blockSize=",
                        "separate": false
                    },
                    "doc": "Number of items to bundle in r-tree.  Default 256\n",
                    "id": "#ucsc-bedtobigbed.cwl/block_size"
                },
                {
                    "type": [
                        "File"
                    ],
                    "inputBinding": {
                        "position": 21
                    },
                    "doc": "Chromosome length files\n",
                    "id": "#ucsc-bedtobigbed.cwl/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 11,
                        "prefix": "-extraIndex=",
                        "separate": false
                    },
                    "doc": "Makes an index on each field in a comma separated list extraIndex=name and extraIndex=name,id are commonly used\n",
                    "id": "#ucsc-bedtobigbed.cwl/extra_index"
                },
                {
                    "type": [
                        "File"
                    ],
                    "inputBinding": {
                        "position": 20
                    },
                    "doc": "Input BED file\n",
                    "id": "#ucsc-bedtobigbed.cwl/input_bed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 8,
                        "prefix": "-itemsPerSlot=",
                        "separate": false
                    },
                    "doc": "Number of data points bundled at lowest level. Default 512\n",
                    "id": "#ucsc-bedtobigbed.cwl/items_per_slot"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 22,
                        "valueFrom": "${\n    if (self == \"\"){\n      return default_output_filename();\n    } else {\n      return self;\n    }\n}\n"
                    },
                    "default": "",
                    "doc": "Output filename\n",
                    "id": "#ucsc-bedtobigbed.cwl/output_filename"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 12,
                        "prefix": "-sizesIs2Bit=",
                        "separate": false
                    },
                    "doc": "If set, the chrom.sizes file is assumed to be a 2bit file\n",
                    "id": "#ucsc-bedtobigbed.cwl/size_2bit"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 10,
                        "prefix": "-tab"
                    },
                    "doc": "If set, expect fields to be tab separated, normally expects white space separator\n",
                    "id": "#ucsc-bedtobigbed.cwl/tab_sep"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 9,
                        "prefix": "-unc"
                    },
                    "doc": "If set, do not use compression\n",
                    "id": "#ucsc-bedtobigbed.cwl/unc"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_filename == \"\"){\n    return default_output_filename();\n  } else {\n    return inputs.output_filename;\n  }\n}\n"
                    },
                    "id": "#ucsc-bedtobigbed.cwl/bigbed_file"
                }
            ],
            "baseCommand": [
                "bedToBigBed"
            ],
            "doc": "Tool converts bed file to bigBed\n\nBefore running `baseCommand` the following files are created in Docker working directory (using\n`InitialWorkDirRequirement`):\n`narrowpeak.as` - default BED file structure template for ENCODE narrowPeak format\n`broadpeak.as`  - default BED file structure template for ENCODE broadPeak format\n\n`default_output_filename` function returns default output file name based on `input_bed` basename with `*.bb`\nextension if `output_filename` is not provided.\n\n`get_bed_type` function returns default BED file type if `bed_type` is not provided. Depending on `input_bed` file\nextension the following values are returned:\n  `*.narrowpeak`  -->   bed6+4\n  `*.broadpeak`   -->   bed6+3\n   else           -->   null (`bedToBigBed` will use its own default value)\n\n`get_bed_template` function returns default BED file template if `bed_template` is not provided. Depending on\n`input_bed` file extension the following values are returned:\n    `*.narrowpeak`  -->   narrowpeak.as (previously staged into Docker working directory)\n    `*.broadpeak`   -->   broadpeak.as (previously staged into Docker working directory)\n     else           -->   null (`bedToBigBed` will use its own default value)\n",
            "id": "#ucsc-bedtobigbed.cwl",
            "http://schema.org/mainEntity": {
                "class": "http://schema.org/SoftwareSourceCode",
                "id": "#ucsc-metadata.yaml",
                "http://schema.org/name": "UCSC userApps",
                "http://schema.org/about": "UCSC genome browser bioinformatic utilities\n",
                "http://schema.org/url": "https://genome.ucsc.edu/util.html",
                "http://schema.org/targetProduct": {
                    "class": "http://schema.org/SoftwareApplication",
                    "http://schema.org/softwareVersion": "v358",
                    "http://schema.org/applicationCategory": "commandline tool",
                    "http://schema.org/downloadURL": "http://hgdownload.cse.ucsc.edu/admin/exe/userApps.v358.src.tgz"
                },
                "http://schema.org/programmingLanguage": "C++",
                "http://schema.org/license": [
                    "https://opensource.org/licenses/GPL-3.0"
                ]
            },
            "http://schema.org/name": "ucsc-bedtobigbed",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/ucsc-bedtobigbed.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage:\n   bedToBigBed in.bed chrom.sizes out.bb\nWhere in.bed is in one of the ascii bed formats, but not including track lines\nand chrom.sizes is a two-column file/URL: <chromosome name> <size in bases>\nand out.bb is the output indexed big bed file.\nIf the assembly <db> is hosted by UCSC, chrom.sizes can be a URL like\n  http://hgdownload.cse.ucsc.edu/goldenPath/<db>/bigZips/<db>.chrom.sizes\nor you may use the script fetchChromSizes to download the chrom.sizes file.\nIf not hosted by UCSC, a chrom.sizes file can be generated by running\ntwoBitInfo on the assembly .2bit file.\nThe in.bed file must be sorted by chromosome,start,\n  to sort a bed file, use the unix sort command:\n     sort -k1,1 -k2,2n unsorted.bed > sorted.bed\nSorting must be set to skip Unicode mapping (LC_COLLATE=C).\n\noptions:\n   -type=bedN[+[P]] :\n                      N is between 3 and 15,\n                      optional (+) if extra \"bedPlus\" fields,\n                      optional P specifies the number of extra fields. Not required, but preferred.\n                      Examples: -type=bed6 or -type=bed6+ or -type=bed6+3\n                      (see http://genome.ucsc.edu/FAQ/FAQformat.html#format1)\n   -as=fields.as - If you have non-standard \"bedPlus\" fields, it's great to put a definition\n                   of each field in a row in AutoSql format here.\n   -blockSize=N - Number of items to bundle in r-tree.  Default 256\n   -itemsPerSlot=N - Number of data points bundled at lowest level. Default 512\n   -unc - If set, do not use compression.\n   -tab - If set, expect fields to be tab separated, normally\n           expects white space separator.\n   -extraIndex=fieldList - If set, make an index on each field in a comma separated list\n           extraIndex=name and extraIndex=name,id are commonly used.\n   -sizesIs2Bit  -- If set, the chrom.sizes file is assumed to be a 2bit file.\n   -udcDir=/path/to/udcCacheDir  -- sets the UDC cache dir for caching of remote files.\n"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:upstream": {
                "first_biological_condition": [
                    "chipseq-se.cwl",
                    "chipseq-pe.cwl",
                    "trim-chipseq-se.cwl",
                    "trim-chipseq-pe.cwl",
                    "trim-atacseq-se.cwl",
                    "trim-atacseq-pe.cwl"
                ],
                "second_biological_condition": [
                    "chipseq-se.cwl",
                    "chipseq-pe.cwl",
                    "trim-chipseq-se.cwl",
                    "trim-chipseq-pe.cwl",
                    "trim-atacseq-se.cwl",
                    "trim-atacseq-pe.cwl"
                ],
                "blocked_condition": [
                    "chipseq-se.cwl",
                    "chipseq-pe.cwl",
                    "trim-chipseq-se.cwl",
                    "trim-chipseq-pe.cwl",
                    "trim-atacseq-se.cwl",
                    "trim-atacseq-pe.cwl"
                ],
                "genome_indices": [
                    "genome-indices.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#main/analysis_method/method",
                            "symbols": [
                                "#main/analysis_method/method/deseq2",
                                "#main/analysis_method/method/edger"
                            ]
                        }
                    ],
                    "default": "edger",
                    "label": "Analysis method",
                    "doc": "Method by which to analyze differential binding affinity. Default: deseq2",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/analysis_method"
                },
                {
                    "type": "File",
                    "label": "Genome annotation",
                    "format": "http://edamontology.org/format_3475",
                    "doc": "Genome annotation file in TSV format",
                    "sd:upstreamSource": "genome_indices/annotation",
                    "id": "#main/annotation_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "default": null,
                    "label": "Blocking attributes for multi-factor analysis. Minimum 2",
                    "doc": "Blocking attributes for multi-factor analysis. Minimum 2.\nEither names from --name1 or/and --name2 or array of strings that can be parsed by R to bool.\nIn the later case the order and size should correspond to [--read1]+[--read2].\nDefault: not applied\n",
                    "sd:upstreamSource": "blocked_condition/alias",
                    "sd:localLabel": true,
                    "id": "#main/blocked_attributes"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "label": "Blocking attribute headerless TSV/CSV file for multi-factor analysis with columns to set name and group. If this inputs is set, blocking attributes above are ignored",
                    "format": "http://edamontology.org/format_2330",
                    "doc": "Blocking attribute metadata file for multi-factor analysis. Headerless TSV/CSV file.\nFirst column - names from --name1 and --name2, second column - group name. --block is ignored\n",
                    "id": "#main/blocked_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "Chromosome length file",
                    "doc": "Chromosome length file",
                    "sd:upstreamSource": "genome_indices/chrom_length",
                    "id": "#main/chrom_length_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#main/cutoff_param/cutoff",
                            "symbols": [
                                "#main/cutoff_param/cutoff/pvalue",
                                "#main/cutoff_param/cutoff/fdr"
                            ]
                        }
                    ],
                    "default": "pvalue",
                    "label": "Parameter to which cutoff should be applied",
                    "doc": "Parameter to which cutoff should be applied (fdr or pvalue). Default: fdr",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/cutoff_param"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "label": "P-value or FDR cutoff for reported results",
                    "doc": "P-value or FDR cutoff for reported results",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/cutoff_value"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 125,
                    "label": "Reads extension size, bp",
                    "doc": "Extended each read from its endpoint along the appropriate strand. Default: 125bp",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/fragmentsize"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3006",
                    "label": "Genome coverage(s) for biological condition 1",
                    "doc": "Genome coverage bigWig file(s) for biological condition 1",
                    "sd:upstreamSource": "first_biological_condition/bigwig",
                    "id": "#main/genome_coverage_files_cond_1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3006",
                    "label": "Genome coverage(s) for biological condition 2",
                    "doc": "Genome coverage bigWig file(s) for biological condition 2",
                    "sd:upstreamSource": "second_biological_condition/bigwig",
                    "id": "#main/genome_coverage_files_cond_2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2,
                    "label": "Minimum peakset overlap",
                    "doc": "Min peakset overlap. Only include peaks in at least this many peaksets when generating consensus peakset. Default: 2",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/min_overlap"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "label": "Minimum read counts. Exclude intervals where MAX read counts for all samples < specified value",
                    "doc": "Min read counts. Exclude all merged intervals where the MAX raw read counts among all of the samples is smaller than the specified value. Default: 0",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/min_read_counts"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "condition_1",
                    "label": "Condition 1 name, single word with letters and numbers only",
                    "doc": "Condition 1 name, single word with letters and numbers only",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/name_cond_1"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "condition_2",
                    "label": "Condition 2 name, single word with letters and numbers only",
                    "doc": "Condition 2 name, single word with letters and numbers only",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/name_cond_2"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "format": "http://edamontology.org/format_3613",
                    "label": "Called peaks for biological condition 1",
                    "doc": "Narrow peaks file(s) for biological condition 1",
                    "sd:upstreamSource": "first_biological_condition/macs2_narrow_peaks",
                    "id": "#main/narrow_peaks_files_cond_1"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "format": "http://edamontology.org/format_3613",
                    "label": "Called peaks for biological condition 2",
                    "doc": "Narrow peaks file(s) for biological condition 2",
                    "sd:upstreamSource": "second_biological_condition/macs2_narrow_peaks",
                    "id": "#main/narrow_peaks_files_cond_2"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3468",
                    "label": "Biological condition 1 samples. Minimum 2 samples",
                    "doc": "XLS peak files for condition 1 from MACS2. Minimim 2 files. Order corresponds to read_files_cond_1",
                    "sd:upstreamSource": "first_biological_condition/macs2_called_peaks",
                    "id": "#main/peak_files_cond_1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3468",
                    "label": "Biological condition 2 samples. Minimum 2 samples",
                    "doc": "XLS peak files for condition 2 from MACS2. Minimim 2 files. Order corresponds to read_files_cond_2",
                    "sd:upstreamSource": "second_biological_condition/macs2_called_peaks",
                    "id": "#main/peak_files_cond_2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1000,
                    "label": "Promoter distance, bp",
                    "doc": "Max distance from gene TSS (in both direction) overlapping which the peak will be assigned to the promoter region. Default: 1000 bp",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/promoter_dist"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_2572",
                    "label": "Biological condition 1 samples. Minimum 2 samples",
                    "doc": "Read files for condition 1. Minimim 2 files in BAM format",
                    "sd:upstreamSource": "first_biological_condition/bambai_pair",
                    "sd:localLabel": true,
                    "id": "#main/read_files_cond_1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_2572",
                    "label": "Biological condition 2 samples. Minimum 2 samples",
                    "doc": "Read files for condition 2. Minimim 2 files in BAM format",
                    "sd:upstreamSource": "second_biological_condition/bambai_pair",
                    "sd:localLabel": true,
                    "id": "#main/read_files_cond_2"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "label": "Remove duplicated reads",
                    "doc": "Remove reads that map to exactly the same genomic position. Default: false",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/remove_duplicates"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "label": "Biological condition 1 sample names",
                    "doc": "Aliases for biological condition 1 samples to make the legend for generated plots. Order corresponds to the read_files_cond_1",
                    "sd:upstreamSource": "first_biological_condition/alias",
                    "id": "#main/sample_names_cond_1"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "label": "Biological condition 2 sample names",
                    "doc": "Aliases for biological condition 2 samples to make the legend for generated plots. Order corresponds to the read_files_cond_2",
                    "sd:upstreamSource": "second_biological_condition/alias",
                    "id": "#main/sample_names_cond_2"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 4,
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/threads"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20000,
                    "label": "Upstream distance, bp",
                    "doc": "Max distance from the promoter (only in upstream direction) overlapping which the peak will be assigned to the upstream region. Default: 20,000 bp",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/upstream_dist"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "label": "Use common peaks within each condition. Ignore Minimum peakset overlap",
                    "doc": "Derive consensus peaks only from the common peaks within each condition. Min peakset overlap is ignored. Default: false",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/use_common"
                }
            ],
            "outputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "Not filtered normalized counts correlation heatmap",
                    "doc": "Not filtered normalized counts correlation heatmap",
                    "outputSource": "#main/select_files/selected_all_norm_counts_corr_heatmap",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "Not filtered normalized counts correlation heatmap"
                            }
                        }
                    ],
                    "id": "#main/diffbind_all_data_correlation_heatmap"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "Not filtered normalized counts correlation heatmap",
                    "doc": "Not filtered normalized counts correlation heatmap",
                    "outputSource": "#main/select_files/selected_all_norm_counts_corr_heatmap_pdf",
                    "id": "#main/diffbind_all_data_correlation_heatmap_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "PCA plot for all bound sites",
                    "doc": "PCA plot for all bound sites",
                    "outputSource": "#main/select_files/selected_all_pca_plot",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "PCA plot for all bound sites"
                            }
                        }
                    ],
                    "id": "#main/diffbind_all_pca_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "PCA plot for all bound sites",
                    "doc": "PCA plot for all bound sites",
                    "outputSource": "#main/select_files/selected_all_pca_plot_pdf",
                    "id": "#main/diffbind_all_pca_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "All peak overlap rate plot",
                    "doc": "All peak overlap rate plot",
                    "outputSource": "#main/diffbind/all_peak_overlap_rate_plot",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "All peak overlap rate plot"
                            }
                        }
                    ],
                    "id": "#main/diffbind_all_peak_overlap_rate_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "All peak overlap rate plot",
                    "doc": "All peak overlap rate plot",
                    "outputSource": "#main/diffbind/all_peak_overlap_rate_plot_pdf",
                    "id": "#main/diffbind_all_peak_overlap_rate_plot_pdf"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3004",
                    "label": "Estimated differential peaks",
                    "doc": "Estimated differential peaks, bigBed",
                    "outputSource": "#main/bed_to_bigbed/bigbed_file",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/diffbind_bed_file/igvbrowser",
                                "type": "annotation",
                                "format": "#main/diffbind_bed_file/bigbed",
                                "name": "#main/diffbind_bed_file/Differential peaks",
                                "height": 40
                            }
                        }
                    ],
                    "id": "#main/diffbind_bed_file"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "Box plots of read distributions for significantly differentially bound sites",
                    "doc": "Box plots of read distributions for significantly differentially bound sites",
                    "outputSource": "#main/select_files/selected_boxplot",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "Box plots of read distributions for significantly differentially bound sites"
                            }
                        }
                    ],
                    "id": "#main/diffbind_boxplot_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "Box plots of read distributions for significantly differentially bound sites",
                    "doc": "Box plots of read distributions for significantly differentially bound sites",
                    "outputSource": "#main/select_files/selected_boxplot_pdf",
                    "id": "#main/diffbind_boxplot_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "Consensus peak Venn Diagram",
                    "doc": "Consensus peak Venn Diagram",
                    "outputSource": "#main/diffbind/consensus_peak_venn_diagram",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "Consensus peak Venn Diagram"
                            }
                        }
                    ],
                    "id": "#main/diffbind_consensus_peak_venn_diagram"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "Consensus peak Venn Diagram",
                    "doc": "Consensus peak Venn Diagram",
                    "outputSource": "#main/diffbind/consensus_peak_venn_diagram_pdf",
                    "id": "#main/diffbind_consensus_peak_venn_diagram_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "Raw counts correlation heatmap",
                    "doc": "Raw counts correlation heatmap",
                    "outputSource": "#main/diffbind/raw_counts_corr_heatmap",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "Raw counts correlation heatmap"
                            }
                        }
                    ],
                    "id": "#main/diffbind_counts_correlation_heatmap"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "Raw counts correlation heatmap",
                    "doc": "Raw counts correlation heatmap",
                    "outputSource": "#main/diffbind/raw_counts_corr_heatmap_pdf",
                    "id": "#main/diffbind_counts_correlation_heatmap_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "Binding heatmap for significantly differentially bound sites",
                    "doc": "Binding heatmap for significantly differentially bound sites",
                    "outputSource": "#main/select_files/selected_binding_heatmap",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "Binding heatmap for significantly differentially bound sites"
                            }
                        }
                    ],
                    "id": "#main/diffbind_db_sites_binding_heatmap"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "Binding heatmap for significantly differentially bound sites",
                    "doc": "Binding heatmap for significantly differentially bound sites",
                    "outputSource": "#main/select_files/selected_binding_heatmap_pdf",
                    "id": "#main/diffbind_db_sites_binding_heatmap_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "Normalized counts correlation heatmap for significantly differentially bound sites",
                    "doc": "Normalized counts correlation heatmap for significantly differentially bound sites",
                    "outputSource": "#main/select_files/selected_diff_filtered_norm_counts_corr_heatmap",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "Normalized counts correlation heatmap for significantly differentially bound sites"
                            }
                        }
                    ],
                    "id": "#main/diffbind_db_sites_correlation_heatmap"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "Normalized counts correlation heatmap for significantly differentially bound sites",
                    "doc": "Normalized counts correlation heatmap for significantly differentially bound sites",
                    "outputSource": "#main/select_files/selected_diff_filtered_norm_counts_corr_heatmap_pdf",
                    "id": "#main/diffbind_db_sites_correlation_heatmap_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "MA plot for significantly differentially bound sites",
                    "doc": "MA plot for significantly differentially bound sites",
                    "outputSource": "#main/select_files/selected_ma_plot",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "MA plot for significantly differentially bound sites"
                            }
                        }
                    ],
                    "id": "#main/diffbind_ma_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "MA plot for significantly differentially bound sites",
                    "doc": "MA plot for significantly differentially bound sites",
                    "outputSource": "#main/select_files/selected_ma_plot_pdf",
                    "id": "#main/diffbind_ma_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "PCA plot for significantly differentially bound sites",
                    "doc": "PCA plot for significantly differentially bound sites",
                    "outputSource": "#main/select_files/selected_diff_filtered_pca_plot",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "PCA plot for significantly differentially bound sites"
                            }
                        }
                    ],
                    "id": "#main/diffbind_pca_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "PCA plot for significantly differentially bound sites",
                    "doc": "PCA plot for significantly differentially bound sites",
                    "outputSource": "#main/select_files/selected_diff_filtered_pca_plot_pdf",
                    "id": "#main/diffbind_pca_plot_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "Peak overlap correlation heatmap",
                    "doc": "Peak overlap correlation heatmap",
                    "outputSource": "#main/diffbind/peak_overlap_corr_heatmap",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "Peak overlap correlation heatmap"
                            }
                        }
                    ],
                    "id": "#main/diffbind_peak_correlation_heatmap"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "Peak overlap correlation heatmap",
                    "doc": "Peak overlap correlation heatmap",
                    "outputSource": "#main/diffbind/peak_overlap_corr_heatmap_pdf",
                    "id": "#main/diffbind_peak_correlation_heatmap_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "Condition 1 peak overlap rate plot",
                    "doc": "Condition 1 peak overlap rate plot",
                    "outputSource": "#main/diffbind/peak_overlap_rate_plot_cond_1",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "Condition 1 peak overlap rate plot"
                            }
                        }
                    ],
                    "id": "#main/diffbind_peak_overlap_rate_plot_cond_1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "Condition 1 peak overlap rate plot",
                    "doc": "Condition 1 peak overlap rate plot",
                    "outputSource": "#main/diffbind/peak_overlap_rate_plot_cond_1_pdf",
                    "id": "#main/diffbind_peak_overlap_rate_plot_cond_1_pdf"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "Condition 2 peak overlap rate plot",
                    "doc": "Condition 2 peak overlap rate plot",
                    "outputSource": "#main/diffbind/peak_overlap_rate_plot_cond_2",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "Condition 2 peak overlap rate plot"
                            }
                        }
                    ],
                    "id": "#main/diffbind_peak_overlap_rate_plot_cond_2"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "Condition 2 peak overlap rate plot",
                    "doc": "Condition 2 peak overlap rate plot",
                    "outputSource": "#main/diffbind/peak_overlap_rate_plot_cond_2_pdf",
                    "id": "#main/diffbind_peak_overlap_rate_plot_cond_2_pdf"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "label": "Differential binding analysis results",
                    "doc": "Differential binding analysis results exported as TSV",
                    "outputSource": "#main/restore_columns/output_file",
                    "sd:visualPlugins": [
                        {
                            "syncfusiongrid": {
                                "tab": "Differential Peak Calling",
                                "Title": "Differential Binding Analysis Results"
                            }
                        }
                    ],
                    "id": "#main/diffbind_report_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "diffbind stderr log",
                    "doc": "diffbind stderr log",
                    "outputSource": "#main/diffbind/stderr_log",
                    "id": "#main/diffbind_stderr_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "diffbind stdout log",
                    "doc": "diffbind stdout log",
                    "outputSource": "#main/diffbind/stdout_log",
                    "id": "#main/diffbind_stdout_log"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3603",
                    "label": "Volcano plot for for significantly differentially bound sites",
                    "doc": "Volcano plot for for significantly differentially bound sites",
                    "outputSource": "#main/select_files/selected_volcano_plot",
                    "sd:visualPlugins": [
                        {
                            "image": {
                                "tab": "Plots",
                                "Caption": "Volcano plot for for significantly differentially bound sites"
                            }
                        }
                    ],
                    "id": "#main/diffbind_volcano_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "label": "Volcano plot for for significantly differentially bound sites",
                    "doc": "Volcano plot for for significantly differentially bound sites",
                    "outputSource": "#main/select_files/selected_volcano_plot_pdf",
                    "id": "#main/diffbind_volcano_plot_pdf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3006",
                    "label": "Genome coverage(s) for biological condition 1",
                    "doc": "Genome coverage bigWig file(s) for biological condition 1",
                    "outputSource": "#main/pipe/coverage_files_cond_1",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/genome_coverage_cond_1/igvbrowser",
                                "type": "wig",
                                "name": "#main/genome_coverage_cond_1/Genome coverage 1",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/genome_coverage_cond_1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "format": "http://edamontology.org/format_3006",
                    "label": "Genome coverage(s) for biological condition 2",
                    "doc": "Genome coverage bigWig file(s) for biological condition 2",
                    "outputSource": "#main/pipe/coverage_files_cond_2",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/genome_coverage_cond_2/igvbrowser",
                                "type": "wig",
                                "name": "#main/genome_coverage_cond_2/Genome coverage 2",
                                "height": 120
                            }
                        }
                    ],
                    "id": "#main/genome_coverage_cond_2"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "format": "http://edamontology.org/format_3613",
                    "label": "Called peaks for biological condition 1",
                    "doc": "Narrow peaks file(s) for biological condition 1",
                    "outputSource": "#main/pipe/peaks_files_cond_1",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/narrow_peaks_cond_1/igvbrowser",
                                "type": "annotation",
                                "name": "#main/narrow_peaks_cond_1/Called peaks 1",
                                "displayMode": "COLLAPSE",
                                "height": 40
                            }
                        }
                    ],
                    "id": "#main/narrow_peaks_cond_1"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "format": "http://edamontology.org/format_3613",
                    "label": "Called peaks for biological condition 2",
                    "doc": "Narrow peaks file(s) for biological condition 2",
                    "outputSource": "#main/pipe/peaks_files_cond_2",
                    "sd:visualPlugins": [
                        {
                            "igvbrowser": {
                                "tab": "IGV Genome Browser",
                                "id": "#main/narrow_peaks_cond_2/igvbrowser",
                                "type": "annotation",
                                "name": "#main/narrow_peaks_cond_2/Called peaks 2",
                                "displayMode": "COLLAPSE",
                                "height": 40
                            }
                        }
                    ],
                    "id": "#main/narrow_peaks_cond_2"
                }
            ],
            "steps": [
                {
                    "run": "#iaintersect.cwl",
                    "in": [
                        {
                            "source": "#main/annotation_file",
                            "id": "#main/assign_genes/annotation_filename"
                        },
                        {
                            "source": "#main/filter_columns/output_file",
                            "id": "#main/assign_genes/input_filename"
                        },
                        {
                            "source": "#main/promoter_dist",
                            "id": "#main/assign_genes/promoter_bp"
                        },
                        {
                            "source": "#main/upstream_dist",
                            "id": "#main/assign_genes/upstream_bp"
                        }
                    ],
                    "out": [
                        "#main/assign_genes/result_file"
                    ],
                    "id": "#main/assign_genes"
                },
                {
                    "run": "#ucsc-bedtobigbed.cwl",
                    "in": [
                        {
                            "default": "bed4+5",
                            "id": "#main/bed_to_bigbed/bed_type"
                        },
                        {
                            "source": "#main/chrom_length_file",
                            "id": "#main/bed_to_bigbed/chrom_length_file"
                        },
                        {
                            "source": "#main/sort_bed/sorted_file",
                            "id": "#main/bed_to_bigbed/input_bed"
                        },
                        {
                            "source": "#main/sort_bed/sorted_file",
                            "valueFrom": "$(self.basename.split('.').slice(0,-1).join('.') + \".bigBed\")",
                            "id": "#main/bed_to_bigbed/output_filename"
                        }
                    ],
                    "out": [
                        "#main/bed_to_bigbed/bigbed_file"
                    ],
                    "id": "#main/bed_to_bigbed"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/restore_columns/output_file",
                            "id": "#main/convert_to_bed/input_file"
                        },
                        {
                            "default": "cat \"$0\" | awk -F \"\\t\" 'NR==1 {for (i=1; i<=NF; i++) {ix[$i]=i} } NR>1 {color=\"255,0,0\"; if ($ix[\"Fold\"]<0) color=\"0,255,0\"; print $ix[\"Chr\"]\"\\t\"$ix[\"Start\"]\"\\t\"$ix[\"End\"]\"\\tPv=\"$ix[\"p-value\"]\";FDR=\"$ix[\"FDR\"]\"\\t\"1000\"\\t\"$ix[\"Strand\"]\"\\t\"$ix[\"Start\"]\"\\t\"$ix[\"End\"]\"\\t\"color}' > `basename $0`\n",
                            "id": "#main/convert_to_bed/script"
                        }
                    ],
                    "out": [
                        "#main/convert_to_bed/output_file"
                    ],
                    "id": "#main/convert_to_bed"
                },
                {
                    "run": "#diffbind.cwl",
                    "in": [
                        {
                            "source": "#main/analysis_method",
                            "id": "#main/diffbind/analysis_method"
                        },
                        {
                            "source": "#main/blocked_attributes",
                            "id": "#main/diffbind/blocked_attributes"
                        },
                        {
                            "source": "#main/blocked_file",
                            "id": "#main/diffbind/blocked_file"
                        },
                        {
                            "source": "#main/cutoff_param",
                            "id": "#main/diffbind/cutoff_param"
                        },
                        {
                            "source": "#main/cutoff_value",
                            "id": "#main/diffbind/cutoff_value"
                        },
                        {
                            "source": "#main/fragmentsize",
                            "id": "#main/diffbind/fragmentsize"
                        },
                        {
                            "source": "#main/min_overlap",
                            "id": "#main/diffbind/min_overlap"
                        },
                        {
                            "source": "#main/min_read_counts",
                            "id": "#main/diffbind/min_read_counts"
                        },
                        {
                            "source": "#main/name_cond_1",
                            "id": "#main/diffbind/name_cond_1"
                        },
                        {
                            "source": "#main/name_cond_2",
                            "id": "#main/diffbind/name_cond_2"
                        },
                        {
                            "source": "#main/peak_files_cond_1",
                            "id": "#main/diffbind/peak_files_cond_1"
                        },
                        {
                            "source": "#main/peak_files_cond_2",
                            "id": "#main/diffbind/peak_files_cond_2"
                        },
                        {
                            "default": "macs",
                            "id": "#main/diffbind/peakformat"
                        },
                        {
                            "source": "#main/read_files_cond_1",
                            "id": "#main/diffbind/read_files_cond_1"
                        },
                        {
                            "source": "#main/read_files_cond_2",
                            "id": "#main/diffbind/read_files_cond_2"
                        },
                        {
                            "source": "#main/remove_duplicates",
                            "id": "#main/diffbind/remove_duplicates"
                        },
                        {
                            "source": "#main/sample_names_cond_1",
                            "id": "#main/diffbind/sample_names_cond_1"
                        },
                        {
                            "source": "#main/sample_names_cond_2",
                            "id": "#main/diffbind/sample_names_cond_2"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/diffbind/threads"
                        },
                        {
                            "source": "#main/use_common",
                            "id": "#main/diffbind/use_common"
                        }
                    ],
                    "out": [
                        "#main/diffbind/diff_filtered_report_deseq",
                        "#main/diffbind/diff_filtered_report_deseq_blocked",
                        "#main/diffbind/diff_filtered_report_edger",
                        "#main/diffbind/diff_filtered_report_edger_blocked",
                        "#main/diffbind/boxplot_deseq",
                        "#main/diffbind/boxplot_deseq_blocked",
                        "#main/diffbind/boxplot_edger",
                        "#main/diffbind/boxplot_edger_blocked",
                        "#main/diffbind/boxplot_deseq_pdf",
                        "#main/diffbind/boxplot_deseq_blocked_pdf",
                        "#main/diffbind/boxplot_edger_pdf",
                        "#main/diffbind/boxplot_edger_blocked_pdf",
                        "#main/diffbind/volcano_plot_deseq",
                        "#main/diffbind/volcano_plot_deseq_blocked",
                        "#main/diffbind/volcano_plot_edger",
                        "#main/diffbind/volcano_plot_edger_blocked",
                        "#main/diffbind/volcano_plot_deseq_pdf",
                        "#main/diffbind/volcano_plot_deseq_blocked_pdf",
                        "#main/diffbind/volcano_plot_edger_pdf",
                        "#main/diffbind/volcano_plot_edger_blocked_pdf",
                        "#main/diffbind/ma_plot_deseq",
                        "#main/diffbind/ma_plot_deseq_blocked",
                        "#main/diffbind/ma_plot_edger",
                        "#main/diffbind/ma_plot_edger_blocked",
                        "#main/diffbind/ma_plot_deseq_pdf",
                        "#main/diffbind/ma_plot_deseq_blocked_pdf",
                        "#main/diffbind/ma_plot_edger_pdf",
                        "#main/diffbind/ma_plot_edger_blocked_pdf",
                        "#main/diffbind/diff_filtered_pca_plot_deseq",
                        "#main/diffbind/diff_filtered_pca_plot_deseq_blocked",
                        "#main/diffbind/diff_filtered_pca_plot_edger",
                        "#main/diffbind/diff_filtered_pca_plot_edger_blocked",
                        "#main/diffbind/diff_filtered_pca_plot_deseq_pdf",
                        "#main/diffbind/diff_filtered_pca_plot_deseq_blocked_pdf",
                        "#main/diffbind/diff_filtered_pca_plot_edger_pdf",
                        "#main/diffbind/diff_filtered_pca_plot_edger_blocked_pdf",
                        "#main/diffbind/all_pca_plot_deseq",
                        "#main/diffbind/all_pca_plot_deseq_blocked",
                        "#main/diffbind/all_pca_plot_edger",
                        "#main/diffbind/all_pca_plot_edger_blocked",
                        "#main/diffbind/all_pca_plot_deseq_pdf",
                        "#main/diffbind/all_pca_plot_deseq_blocked_pdf",
                        "#main/diffbind/all_pca_plot_edger_pdf",
                        "#main/diffbind/all_pca_plot_edger_blocked_pdf",
                        "#main/diffbind/binding_heatmap_deseq",
                        "#main/diffbind/binding_heatmap_deseq_blocked",
                        "#main/diffbind/binding_heatmap_edger",
                        "#main/diffbind/binding_heatmap_edger_blocked",
                        "#main/diffbind/binding_heatmap_deseq_pdf",
                        "#main/diffbind/binding_heatmap_deseq_blocked_pdf",
                        "#main/diffbind/binding_heatmap_edger_pdf",
                        "#main/diffbind/binding_heatmap_edger_blocked_pdf",
                        "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_deseq",
                        "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_deseq_blocked",
                        "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_edger",
                        "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_edger_blocked",
                        "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_deseq_pdf",
                        "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_deseq_blocked_pdf",
                        "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_edger_pdf",
                        "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_edger_blocked_pdf",
                        "#main/diffbind/all_norm_counts_corr_heatmap_deseq",
                        "#main/diffbind/all_norm_counts_corr_heatmap_deseq_blocked",
                        "#main/diffbind/all_norm_counts_corr_heatmap_edger",
                        "#main/diffbind/all_norm_counts_corr_heatmap_edger_blocked",
                        "#main/diffbind/all_norm_counts_corr_heatmap_deseq_pdf",
                        "#main/diffbind/all_norm_counts_corr_heatmap_deseq_blocked_pdf",
                        "#main/diffbind/all_norm_counts_corr_heatmap_edger_pdf",
                        "#main/diffbind/all_norm_counts_corr_heatmap_edger_blocked_pdf",
                        "#main/diffbind/consensus_peak_venn_diagram",
                        "#main/diffbind/raw_counts_corr_heatmap",
                        "#main/diffbind/peak_overlap_corr_heatmap",
                        "#main/diffbind/all_peak_overlap_rate_plot",
                        "#main/diffbind/peak_overlap_rate_plot_cond_1",
                        "#main/diffbind/peak_overlap_rate_plot_cond_2",
                        "#main/diffbind/consensus_peak_venn_diagram_pdf",
                        "#main/diffbind/raw_counts_corr_heatmap_pdf",
                        "#main/diffbind/peak_overlap_corr_heatmap_pdf",
                        "#main/diffbind/all_peak_overlap_rate_plot_pdf",
                        "#main/diffbind/peak_overlap_rate_plot_cond_1_pdf",
                        "#main/diffbind/peak_overlap_rate_plot_cond_2_pdf",
                        "#main/diffbind/stdout_log",
                        "#main/diffbind/stderr_log"
                    ],
                    "id": "#main/diffbind"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/diff_filtered_report_deseq",
                                "#main/diffbind/diff_filtered_report_deseq_blocked",
                                "#main/diffbind/diff_filtered_report_edger",
                                "#main/diffbind/diff_filtered_report_edger_blocked"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/filter_columns/input_file"
                        },
                        {
                            "default": "cat $0 | grep -v \"Start\" | awk 'BEGIN {print \"chr\\tstart\\tend\\tlength\\tabs_summit\\tpileup\\t-log10(pvalue)\\tfold_enrichment\\t-log10(qvalue)\\tname\"} {print $1\"\\t\"$2\"\\t\"$3\"\\t\"$3-$2+1\"\\t0\\t\"NR\"\\t0\\t0\\t0\\t0\"}' > `basename $0`\n",
                            "id": "#main/filter_columns/script"
                        }
                    ],
                    "out": [
                        "#main/filter_columns/output_file"
                    ],
                    "id": "#main/filter_columns"
                },
                {
                    "run": {
                        "cwlVersion": "v1.0",
                        "class": "ExpressionTool",
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/pipe/d397a264-30a9-4461-99e3-c0844d59fe14/genome_coverage_files_cond_1"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/pipe/d397a264-30a9-4461-99e3-c0844d59fe14/genome_coverage_files_cond_2"
                            },
                            {
                                "type": [
                                    "null",
                                    {
                                        "type": "array",
                                        "items": "File"
                                    }
                                ],
                                "id": "#main/pipe/d397a264-30a9-4461-99e3-c0844d59fe14/narrow_peaks_files_cond_1"
                            },
                            {
                                "type": [
                                    "null",
                                    {
                                        "type": "array",
                                        "items": "File"
                                    }
                                ],
                                "id": "#main/pipe/d397a264-30a9-4461-99e3-c0844d59fe14/narrow_peaks_files_cond_2"
                            }
                        ],
                        "outputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/pipe/d397a264-30a9-4461-99e3-c0844d59fe14/coverage_files_cond_1"
                            },
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "id": "#main/pipe/d397a264-30a9-4461-99e3-c0844d59fe14/coverage_files_cond_2"
                            },
                            {
                                "type": [
                                    "null",
                                    {
                                        "type": "array",
                                        "items": "File"
                                    }
                                ],
                                "id": "#main/pipe/d397a264-30a9-4461-99e3-c0844d59fe14/peaks_files_cond_1"
                            },
                            {
                                "type": [
                                    "null",
                                    {
                                        "type": "array",
                                        "items": "File"
                                    }
                                ],
                                "id": "#main/pipe/d397a264-30a9-4461-99e3-c0844d59fe14/peaks_files_cond_2"
                            }
                        ],
                        "expression": "${\n  return {\n    \"coverage_files_cond_1\": inputs.genome_coverage_files_cond_1,\n    \"coverage_files_cond_2\": inputs.genome_coverage_files_cond_2,\n    \"peaks_files_cond_1\": inputs.narrow_peaks_files_cond_1,\n    \"peaks_files_cond_2\": inputs.narrow_peaks_files_cond_2\n  };\n}\n",
                        "id": "#main/pipe/d397a264-30a9-4461-99e3-c0844d59fe14"
                    },
                    "in": [
                        {
                            "source": "#main/genome_coverage_files_cond_1",
                            "id": "#main/pipe/genome_coverage_files_cond_1"
                        },
                        {
                            "source": "#main/genome_coverage_files_cond_2",
                            "id": "#main/pipe/genome_coverage_files_cond_2"
                        },
                        {
                            "source": "#main/narrow_peaks_files_cond_1",
                            "id": "#main/pipe/narrow_peaks_files_cond_1"
                        },
                        {
                            "source": "#main/narrow_peaks_files_cond_2",
                            "id": "#main/pipe/narrow_peaks_files_cond_2"
                        }
                    ],
                    "out": [
                        "#main/pipe/coverage_files_cond_1",
                        "#main/pipe/coverage_files_cond_2",
                        "#main/pipe/peaks_files_cond_1",
                        "#main/pipe/peaks_files_cond_2"
                    ],
                    "id": "#main/pipe"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/diff_filtered_report_deseq",
                                "#main/diffbind/diff_filtered_report_deseq_blocked",
                                "#main/diffbind/diff_filtered_report_edger",
                                "#main/diffbind/diff_filtered_report_edger_blocked",
                                "#main/assign_genes/result_file"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return [self[6], self[2]];\n      } else {\n        return [self[6], self[3]];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return [self[6], self[4]];\n      } else {\n        return [self[6], self[5]];\n      }\n    }\n}\n",
                            "id": "#main/restore_columns/input_file"
                        },
                        {
                            "default": "cat $0 | grep -v \"start\" | sort -k 11n | cut -f 1-5,15 > iaintersect_result.tsv\ncat $1 | grep -v \"Start\" > diffbind_result.tsv\nHEADER=`head -n 1 $1`;\necho -e \"Refseq_id\\tGene_id\\ttxStart\\ttxEnd\\tStrand\\tRegion\\t${HEADER}\" > `basename $0`;\ncat iaintersect_result.tsv | paste - diffbind_result.tsv >> `basename $0`\nrm iaintersect_result.tsv diffbind_result.tsv\n",
                            "id": "#main/restore_columns/script"
                        }
                    ],
                    "out": [
                        "#main/restore_columns/output_file"
                    ],
                    "id": "#main/restore_columns"
                },
                {
                    "in": [
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/all_norm_counts_corr_heatmap_deseq",
                                "#main/diffbind/all_norm_counts_corr_heatmap_deseq_blocked",
                                "#main/diffbind/all_norm_counts_corr_heatmap_edger",
                                "#main/diffbind/all_norm_counts_corr_heatmap_edger_blocked"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_all_norm_counts_corr_heatmap"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/all_norm_counts_corr_heatmap_deseq_pdf",
                                "#main/diffbind/all_norm_counts_corr_heatmap_deseq_blocked_pdf",
                                "#main/diffbind/all_norm_counts_corr_heatmap_edger_pdf",
                                "#main/diffbind/all_norm_counts_corr_heatmap_edger_blocked_pdf"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_all_norm_counts_corr_heatmap_pdf"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/all_pca_plot_deseq",
                                "#main/diffbind/all_pca_plot_deseq_blocked",
                                "#main/diffbind/all_pca_plot_edger",
                                "#main/diffbind/all_pca_plot_edger_blocked"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_all_pca_plot"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/all_pca_plot_deseq_pdf",
                                "#main/diffbind/all_pca_plot_deseq_blocked_pdf",
                                "#main/diffbind/all_pca_plot_edger_pdf",
                                "#main/diffbind/all_pca_plot_edger_blocked_pdf"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_all_pca_plot_pdf"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/binding_heatmap_deseq",
                                "#main/diffbind/binding_heatmap_deseq_blocked",
                                "#main/diffbind/binding_heatmap_edger",
                                "#main/diffbind/binding_heatmap_edger_blocked"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_binding_heatmap"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/binding_heatmap_deseq_pdf",
                                "#main/diffbind/binding_heatmap_deseq_blocked_pdf",
                                "#main/diffbind/binding_heatmap_edger_pdf",
                                "#main/diffbind/binding_heatmap_edger_blocked_pdf"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_binding_heatmap_pdf"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/boxplot_deseq",
                                "#main/diffbind/boxplot_deseq_blocked",
                                "#main/diffbind/boxplot_edger",
                                "#main/diffbind/boxplot_edger_blocked"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_boxplot"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/boxplot_deseq_pdf",
                                "#main/diffbind/boxplot_deseq_blocked_pdf",
                                "#main/diffbind/boxplot_edger_pdf",
                                "#main/diffbind/boxplot_edger_blocked_pdf"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_boxplot_pdf"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_deseq",
                                "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_deseq_blocked",
                                "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_edger",
                                "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_edger_blocked"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_diff_filtered_norm_counts_corr_heatmap"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_deseq_pdf",
                                "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_deseq_blocked_pdf",
                                "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_edger_pdf",
                                "#main/diffbind/diff_filtered_norm_counts_corr_heatmap_edger_blocked_pdf"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_diff_filtered_norm_counts_corr_heatmap_pdf"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/diff_filtered_pca_plot_deseq",
                                "#main/diffbind/diff_filtered_pca_plot_deseq_blocked",
                                "#main/diffbind/diff_filtered_pca_plot_edger",
                                "#main/diffbind/diff_filtered_pca_plot_edger_blocked"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_diff_filtered_pca_plot"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/diff_filtered_pca_plot_deseq_pdf",
                                "#main/diffbind/diff_filtered_pca_plot_deseq_blocked_pdf",
                                "#main/diffbind/diff_filtered_pca_plot_edger_pdf",
                                "#main/diffbind/diff_filtered_pca_plot_edger_blocked_pdf"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_diff_filtered_pca_plot_pdf"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/ma_plot_deseq",
                                "#main/diffbind/ma_plot_deseq_blocked",
                                "#main/diffbind/ma_plot_edger",
                                "#main/diffbind/ma_plot_edger_blocked"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_ma_plot"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/ma_plot_deseq_pdf",
                                "#main/diffbind/ma_plot_deseq_blocked_pdf",
                                "#main/diffbind/ma_plot_edger_pdf",
                                "#main/diffbind/ma_plot_edger_blocked_pdf"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_ma_plot_pdf"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/volcano_plot_deseq",
                                "#main/diffbind/volcano_plot_deseq_blocked",
                                "#main/diffbind/volcano_plot_edger",
                                "#main/diffbind/volcano_plot_edger_blocked"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_volcano_plot"
                        },
                        {
                            "source": [
                                "#main/analysis_method",
                                "#main/blocked_attributes",
                                "#main/diffbind/volcano_plot_deseq_pdf",
                                "#main/diffbind/volcano_plot_deseq_blocked_pdf",
                                "#main/diffbind/volcano_plot_edger_pdf",
                                "#main/diffbind/volcano_plot_edger_blocked_pdf"
                            ],
                            "valueFrom": "${\n    if (self[0] == \"deseq2\") {\n      if (self[1] == null || self[1].length == 0){\n        return self[2];\n      } else {\n        return self[3];\n      }\n    } else {\n      if (self[1] == null || self[1].length == 0){\n        return self[4];\n      } else {\n        return self[5];\n      }\n    }\n}\n",
                            "id": "#main/select_files/input_volcano_plot_pdf"
                        }
                    ],
                    "out": [
                        "#main/select_files/selected_boxplot",
                        "#main/select_files/selected_volcano_plot",
                        "#main/select_files/selected_ma_plot",
                        "#main/select_files/selected_diff_filtered_pca_plot",
                        "#main/select_files/selected_all_pca_plot",
                        "#main/select_files/selected_binding_heatmap",
                        "#main/select_files/selected_diff_filtered_norm_counts_corr_heatmap",
                        "#main/select_files/selected_all_norm_counts_corr_heatmap",
                        "#main/select_files/selected_boxplot_pdf",
                        "#main/select_files/selected_volcano_plot_pdf",
                        "#main/select_files/selected_ma_plot_pdf",
                        "#main/select_files/selected_diff_filtered_pca_plot_pdf",
                        "#main/select_files/selected_all_pca_plot_pdf",
                        "#main/select_files/selected_binding_heatmap_pdf",
                        "#main/select_files/selected_diff_filtered_norm_counts_corr_heatmap_pdf",
                        "#main/select_files/selected_all_norm_counts_corr_heatmap_pdf"
                    ],
                    "run": {
                        "cwlVersion": "v1.0",
                        "class": "ExpressionTool",
                        "requirements": [
                            {
                                "class": "InlineJavascriptRequirement"
                            }
                        ],
                        "inputs": [
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_all_norm_counts_corr_heatmap"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_all_norm_counts_corr_heatmap_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_all_pca_plot"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_all_pca_plot_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_binding_heatmap"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_binding_heatmap_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_boxplot"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_boxplot_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_diff_filtered_norm_counts_corr_heatmap"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_diff_filtered_norm_counts_corr_heatmap_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_diff_filtered_pca_plot"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_diff_filtered_pca_plot_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_ma_plot"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_ma_plot_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_volcano_plot"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/input_volcano_plot_pdf"
                            }
                        ],
                        "outputs": [
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_all_norm_counts_corr_heatmap"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_all_norm_counts_corr_heatmap_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_all_pca_plot"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_all_pca_plot_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_binding_heatmap"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_binding_heatmap_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_boxplot"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_boxplot_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_diff_filtered_norm_counts_corr_heatmap"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_diff_filtered_norm_counts_corr_heatmap_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_diff_filtered_pca_plot"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_diff_filtered_pca_plot_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_ma_plot"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_ma_plot_pdf"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_volcano_plot"
                            },
                            {
                                "type": [
                                    "null",
                                    "File"
                                ],
                                "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9/selected_volcano_plot_pdf"
                            }
                        ],
                        "expression": "${\n  return {\n    \"selected_boxplot\": inputs.input_boxplot,\n    \"selected_volcano_plot\": inputs.input_volcano_plot,\n    \"selected_ma_plot\": inputs.input_ma_plot,\n    \"selected_diff_filtered_pca_plot\": inputs.input_diff_filtered_pca_plot,\n    \"selected_all_pca_plot\": inputs.input_all_pca_plot,\n    \"selected_binding_heatmap\": inputs.input_binding_heatmap,\n    \"selected_diff_filtered_norm_counts_corr_heatmap\": inputs.input_diff_filtered_norm_counts_corr_heatmap,\n    \"selected_all_norm_counts_corr_heatmap\": inputs.input_all_norm_counts_corr_heatmap,\n    \"selected_boxplot_pdf\": inputs.input_boxplot_pdf,\n    \"selected_volcano_plot_pdf\": inputs.input_volcano_plot_pdf,\n    \"selected_ma_plot_pdf\": inputs.input_ma_plot_pdf,\n    \"selected_diff_filtered_pca_plot_pdf\": inputs.input_diff_filtered_pca_plot_pdf,\n    \"selected_all_pca_plot_pdf\": inputs.input_all_pca_plot_pdf,\n    \"selected_binding_heatmap_pdf\": inputs.input_binding_heatmap_pdf,\n    \"selected_diff_filtered_norm_counts_corr_heatmap_pdf\": inputs.input_diff_filtered_norm_counts_corr_heatmap_pdf,\n    \"selected_all_norm_counts_corr_heatmap_pdf\": inputs.input_all_norm_counts_corr_heatmap_pdf\n  };\n}\n",
                        "id": "#main/select_files/0d477648-7baa-4b84-831b-56cfb29293a9"
                    },
                    "id": "#main/select_files"
                },
                {
                    "run": "#linux-sort.cwl",
                    "in": [
                        {
                            "default": [
                                "1,1",
                                "2,2n"
                            ],
                            "id": "#main/sort_bed/key"
                        },
                        {
                            "source": "#main/convert_to_bed/output_file",
                            "id": "#main/sort_bed/unsorted_file"
                        }
                    ],
                    "out": [
                        "#main/sort_bed/sorted_file"
                    ],
                    "id": "#main/sort_bed"
                }
            ],
            "label": "DiffBind - Differential Binding Analysis of ChIP-Seq Peak Data",
            "doc": "Differential Binding Analysis of ChIP-Seq Peak Data\n---------------------------------------------------\n\nDiffBind processes ChIP-Seq data enriched for genomic loci where specific protein/DNA binding occurs, including peak sets identified by ChIP-Seq peak callers and\naligned sequence read datasets. It is designed to work with multiple peak sets simultaneously, representing different ChIP experiments (antibodies, transcription\nfactor and/or histone marks, experimental conditions, replicates) as well as managing the results of multiple peak callers.\n\nFor more information please refer to:\n-------------------------------------\nRoss-Innes CS, Stark R, Teschendorff AE, Holmes KA, Ali HR, Dunning MJ, Brown GD, Gojis O, Ellis IO, Green AR, Ali S, Chin S, Palmieri C, Caldas C, Carroll JS (2012).\n\u201cDifferential oestrogen receptor binding is associated with clinical outcome in breast cancer.\u201d Nature, 481, -4.",
            "id": "#main",
            "http://schema.org/name": "DiffBind - Differential Binding Analysis of ChIP-Seq Peak Data",
            "http://schema.org/alternateName": "Compute differentially bound sites from multiple ChIP-seq experiments using affinity (quantitative) and occupancy data.",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/diffbind.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://github.com/schemaorg/schemaorg/raw/main/data/releases/11.01/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
